@@ -4,7 +4,7 @@ use Text::Balanced ':ALL';
 
 use vars qw{ $VERSION @EXPORT };
 
-$VERSION = '0.92_01';
+$VERSION = '0.93_01';
 
 use Filter::Util::Call;
 use Carp;
@@ -159,7 +159,7 @@ sub gen_std_filter_for {
                 # single-quoted],<<EOM);
                 # EOM
             my @following_lines;
-            my $whole_line = qr/((?:[^$;\r\n]+|$;....$;)*$nl)/s;
+            my $whole_line = qr/((?:[^$;\r\n]+|$;....$;)*(?:$nl|\z))/s;
             @res = map {
                        if( ! defined ) {
                            ''
@@ -193,7 +193,6 @@ sub gen_std_filter_for {
                        };
                    } /$whole_line/g;
 
-
             $_ = join "", @res;
         }
         else {
@@ -266,6 +265,7 @@ sub gen_filter_import {
                     if ($terminator{terminator} &&
                         m/$terminator{terminator}/) {
                         $lastline = $_;
+                        $count++;
                         last;
                     }
                     $data .= $_;
